@@ -333,21 +333,21 @@ main (int argc, char * argv [])
 	   break;
 	}
 
-	if (*opt == 'd')	display_name = val;	/* "d", "display" */
-	else if (*opt == 'g')	rs_geometry = val;	/* "g", "geometry" */
+	if (*opt == 'd' && val)		display_name = val;	/* "d", "display" */
+	else if (*opt == 'g' && val)	rs_geometry = val;	/* "g", "geometry" */
 #ifdef ICONWIN
-	else if (*opt == 'i')	/* "ic", "iconic" */
+	else if (*opt == 'i' && val)	/* "ic", "iconic" */
 	  {
 	     iconic_state = IconicState;
 	     i--;	/* no argument */
 	  }
 #endif
-	else if (!strcmp (opt, "fg"))		rs_color [fgColor] = val;
-	else if (!strcmp (opt, "bg"))		rs_color [bgColor] = val;
+	else if (!strcmp (opt, "fg") && val)	rs_color [fgColor] = val;
+	else if (!strcmp (opt, "bg") && val)	rs_color [bgColor] = val;
 #ifdef REMINDERS
-	else if (!strcmp (opt, "fn"))		rs_font = val;
+	else if (!strcmp (opt, "fn") && val)	rs_font = val;
 #endif
-	else if (!strcmp (opt, "update"))
+	else if (!strcmp (opt, "update") && val)
 	  {
 	     int x = atoi (val);
 	     if (x < 1 || x > 60)
@@ -356,7 +356,7 @@ main (int argc, char * argv [])
 	       clockUpdate = x;
 	  }
 #ifdef MAIL
-	else if (!strcmp (opt, "mail"))
+	else if (!strcmp (opt, "mail") && val)
 	  {
 	     int x = atoi (val);
 	     if (x < 1)
@@ -366,7 +366,7 @@ main (int argc, char * argv [])
 	  }
 #endif	/* MAIL */
 #ifdef ADJUST_TIME
-	else if (!strcmp (opt, "adjust"))
+	else if (!strcmp (opt, "adjust") && val)
 	  {
 	     /* convert ddhhmm to seconds, minimal error checking */
 	     int x = atoi (val);
