@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	command.c
  *----------------------------------------------------------------------*
- * $Id: command.c,v 1.85.2.23 1999/08/12 16:32:39 mason Exp $
+ * $Id: command.c,v 1.85.2.25 2000/01/04 11:20:02 mason Exp $
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (C) 1992      John Bovey, University of Kent at Canterbury <jdb@ukc.ac.uk>
@@ -1139,6 +1139,7 @@ lookup_key(XEvent * ev)
 		return;
 	    }
 	}
+#ifdef SCROLL_ON_UPDOWN_KEYS
 	if (IS_SCROLL_MOD) {
 	    if (keysym == XK_Up) {
 		scr_page(UP, 1);
@@ -1148,6 +1149,7 @@ lookup_key(XEvent * ev)
 		return;
 	    }
 	}
+#endif
     }
 
     if (shft) {
@@ -3212,19 +3214,24 @@ int
 RemoveFromCNQueue(int width, int height)
 {
     XCNQueue_t     *rq, *prq;
+    int		    new_ncol, new_nrow;
 
 /*
  * If things are working properly we should only need to check the first one
  */
     for (rq = XCNQueue, prq = NULL; rq; rq = rq->next) {
 	if (rq->width == width && rq->height == height) {
-	/* unlink rq */
-	    if (prq)
-		prq->next = rq->next;
-	    else
-		XCNQueue = rq->next;
-	    FREE(rq);
-	    return 1;
+	    new_ncol = (width - szHint.base_width) / TermWin.fwidth;
+	    new_nrow = (height - szHint.base_height) / TermWin.fheight;
+	    if (new_ncol == TermWin.ncol && new_nrow == TermWin.nrow) {
+	    /* unlink rq */
+		if (prq)
+		    prq->next = rq->next;
+		else
+		    XCNQueue = rq->next;
+		FREE(rq);
+		return 1;
+	    }
 	}
 	prq = rq;
     }
