@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	graphics.c
  *----------------------------------------------------------------------*
- * $Id: graphics.c,v 1.17 1998/11/16 07:07:37 mason Exp $
+ * $Id: graphics.c,v 1.19 1999/04/16 05:44:06 mason Exp $
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (C) 1994      Rob Nation <nation@rocket.sanders.lockheed.com>
@@ -50,12 +50,12 @@ static grwin_t *gr_root = NULL;
 /*----------------------------------------------------------------------*
  * local functions
  */
+#ifdef RXVT_GRAPHICS
 /* ARGSUSED */
 /* INTPROTO */
 void
 Gr_NewWindow(int nargs, int args[])
 {
-#ifdef RXVT_GRAPHICS
     int             x, y;
     unsigned int    w, h;
     Window          win;
@@ -98,7 +98,6 @@ Gr_NewWindow(int nargs, int args[])
     graphics_up++;
 
     tt_printf("\033W%ld\n", (long)grwin->win);
-#endif
 }
 
 /* ARGSUSED */
@@ -106,7 +105,6 @@ Gr_NewWindow(int nargs, int args[])
 void
 Gr_ClearWindow(grwin_t *grwin)
 {
-#ifdef RXVT_GRAPHICS
     grcmd_t        *cmd, *next;
 
     for (cmd = grwin->graphics; cmd != NULL; cmd = next) {
@@ -118,7 +116,6 @@ Gr_ClearWindow(grwin_t *grwin)
     }
     grwin->graphics = NULL;
     XClearWindow(Xdisplay, grwin->win);
-#endif
 }
 
 /*
@@ -132,7 +129,6 @@ Gr_ClearWindow(grwin_t *grwin)
 void
 Gr_Text(grwin_t *grwin, grcmd_t *data)
 {
-#ifdef RXVT_GRAPHICS
     int             x, y, align;
 
     if (data->ncoords < 4 || data->text == NULL || *(data->text) == '\0')
@@ -162,7 +158,6 @@ Gr_Text(grwin_t *grwin, grcmd_t *data)
 		 Height2Pixel(1), 0);
     XDrawString(Xdisplay, grwin->win, TermWin.gc, x, y,
 		data->text, data->coords[3]);
-#endif
 }
 
 /* ARGSUSED */
@@ -170,7 +165,6 @@ Gr_Text(grwin_t *grwin, grcmd_t *data)
 void
 Gr_Geometry(grwin_t *grwin, grcmd_t *data)
 {
-#ifdef RXVT_GRAPHICS
     if (grwin)
 	tt_printf("\033G%ld %d %d %u %u %d %d %ld %ld %d\n",
 		  (long)grwin->win,
@@ -191,7 +185,6 @@ Gr_Geometry(grwin_t *grwin, grcmd_t *data)
 		  (long)GRX_SCALE * TermWin.fheight
 		        / (TermWin.height - 2 * TermWin_internalBorder),
 		  Xdepth);
-#endif
 }
 
 /* ARGSUSED */
@@ -199,7 +192,6 @@ Gr_Geometry(grwin_t *grwin, grcmd_t *data)
 void
 Gr_DestroyWindow(grwin_t *grwin)
 {
-#ifdef RXVT_GRAPHICS
     grcmd_t        *cmd, *next;
 
     if (grwin == NULL)
@@ -223,7 +215,6 @@ Gr_DestroyWindow(grwin_t *grwin)
     free(grwin);
 
     graphics_up--;
-#endif
 }
 
 /* ARGSUSED */
@@ -231,7 +222,6 @@ Gr_DestroyWindow(grwin_t *grwin)
 void
 Gr_Dispatch(grwin_t *grwin, grcmd_t *data)
 {
-#ifdef RXVT_GRAPHICS
     int             i, n;
     union {
 	XPoint          pt[NGRX_PTS / 2];
@@ -302,7 +292,6 @@ Gr_Dispatch(grwin_t *grwin, grcmd_t *data)
 	gcv.foreground = PixColors[Color_fg];
 	XChangeGC(Xdisplay, TermWin.gc, GCForeground, &gcv);
     }
-#endif
 }
 
 /* ARGSUSED */
@@ -310,13 +299,12 @@ Gr_Dispatch(grwin_t *grwin, grcmd_t *data)
 void
 Gr_Redraw(grwin_t *grwin)
 {
-#ifdef RXVT_GRAPHICS
     grcmd_t        *cmd;
 
     for (cmd = grwin->graphics; cmd != NULL; cmd = cmd->next)
 	Gr_Dispatch(grwin, cmd);
-#endif
 }
+#endif				/* RXVT_GRAPHICS */
 
 /*----------------------------------------------------------------------*
  * end of static functions
@@ -330,10 +318,10 @@ Gr_ButtonReport(int but, int x, int y)
     grwin_t        *grwin;
 
     for (grwin = gr_root; grwin != NULL; grwin = grwin->next)
-	if ((x > grwin->x) &&
-	    (y > grwin->y) &&
-	    (x < grwin->x + grwin->w) &&
-	    (y < grwin->y + grwin->h))
+	if ((x > grwin->x)
+	    && (y > grwin->y)
+	    && (x < grwin->x + grwin->w)
+	    && (y < grwin->y + grwin->h))
 	    break;
 
     if (grwin == NULL)
@@ -406,10 +394,10 @@ Gr_do_graphics(int cmd, int nargs, int args[], unsigned char *text)
  */
     if ((newcmd->cmd == 'F') && (grwin) && (grwin->graphics)) {
 	for (i = 0; i < newcmd->ncoords; i += 4) {
-	    if ((newcmd->coords[i] == 0) &&
-		(newcmd->coords[i + 1] == 0) &&
-		(newcmd->coords[i + 2] == GRX_SCALE) &&
-		(newcmd->coords[i + 3] == GRX_SCALE)) {
+	    if ((newcmd->coords[i] == 0)
+		&& (newcmd->coords[i + 1] == 0)
+		&& (newcmd->coords[i + 2] == GRX_SCALE)
+		&& (newcmd->coords[i + 3] == GRX_SCALE)) {
 	    /* drop previous commands */
 		oldcmd = grwin->graphics;
 		while (oldcmd->next != NULL) {
