@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	main.c
  *----------------------------------------------------------------------*
- * $Id: main.c,v 1.66.2.7 1999/08/17 08:11:03 mason Exp $
+ * $Id: main.c,v 1.66.2.10 2000/01/26 23:31:19 mason Exp $
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (C) 1992      John Bovey, University of Canterbury
@@ -341,7 +341,7 @@ Create_Windows(int argc, const char * const *argv)
 
 #ifdef PREFER_24BIT
     attributes.background_pixel = PixColors[Color_fg];
-    attributes.border_pixel = PixColors[Color_fg];
+    attributes.border_pixel = PixColors[Color_border];
     attributes.colormap = Xcmap;
     TermWin.parent[0] = XCreateWindow(Xdisplay, Xroot,
 				   szHint.x, szHint.y,
@@ -356,7 +356,7 @@ Create_Windows(int argc, const char * const *argv)
 					 szHint.x, szHint.y,
 					 szHint.width, szHint.height,
 					 BORDERWIDTH,
-					 PixColors[Color_bg],
+					 PixColors[Color_border],
 					 PixColors[Color_fg]);
 #endif
     xterm_seq(XTerm_title, rs[Rs_title]);
@@ -476,7 +476,7 @@ resize_subwindows(int width, int height)
 #ifndef XTERM_SCROLLBAR
     /* arrows are as high as wide - leave 1 pixel gap */
 # ifdef NEXT_SCROLLBAR
-	scrollBar.end -= ((SB_WIDTH - 1) * 2);
+	scrollBar.end -= SB_BUTTON_TOTAL_HEIGHT + SB_PADDING;
 # else
 	scrollBar.beg += (SB_WIDTH + 1) + sb_shadow;
 	scrollBar.end -= (SB_WIDTH + 1) + sb_shadow;
@@ -843,8 +843,9 @@ void
 change_font(int init, const char *fontname)
 {
     const char     *msg = "can't load font \"%s\"";
-    XFontStruct    *xfont;
     int             idx = 0;	/* index into rs[Rs_font] */
+    int             recheckfonts;
+    XFontStruct    *xfont;
     static char    *newfont[NFONTS];
     static int      fnum;		/* logical font number */
 #ifndef NO_BOLDFONT
@@ -987,24 +988,15 @@ change_font(int init, const char *fontname)
     {
 	int             i, cw, fh, fw = 0;
 
-	fw = TermWin.font->min_bounds.width;
+	fw = get_fontwidest(TermWin.font);
 	fh = TermWin.font->ascent + TermWin.font->descent;
 
-	if (TermWin.font->min_bounds.width == TermWin.font->max_bounds.width)
+	if (fw == TermWin.font->min_bounds.width)
 	    TermWin.fprop = 0;	/* Mono-spaced (fixed width) font */
 	else
 	    TermWin.fprop = 1;	/* Proportional font */
 
-	if (TermWin.fprop == 1)	/* also, if == 0, per_char[] might be NULL */
-	    for (i = TermWin.font->max_char_or_byte2
-		     - TermWin.font->min_char_or_byte2;
-		 --i >= 0; ) {
-		cw = TermWin.font->per_char[i].width;
-		MAX_IT(fw, cw);
-	    }
-    /* not the first time thru and sizes haven't changed */
-	if (fw == TermWin.fwidth && fh == TermWin.fheight)
-	    return;		/* TODO: not return; check MULTI if needed */
+	recheckfonts = !(fw == TermWin.fwidth && fh == TermWin.fheight);
 
 	TermWin.fwidth = fw;
 	TermWin.fheight = fh;
@@ -1012,28 +1004,33 @@ change_font(int init, const char *fontname)
 
 /* check that size of boldFont is okay */
 #ifndef NO_BOLDFONT
-    TermWin.boldFont = NULL;
-    if (boldFont != NULL) {
-	int             i, cw, fh, fw = 0;
+    if (recheckfonts) {
+	TermWin.boldFont = NULL;
+	if (boldFont != NULL) {
+	    int             fh, fw;
 
-	fw = boldFont->min_bounds.width;
-	fh = boldFont->ascent + boldFont->descent;
-	if (TermWin.fprop == 0) {	/* bold font must also be monospaced */
-	    if (fw != boldFont->max_bounds.width)
-		fw = -1;
-	} else
-	    for (i = TermWin.font->max_char_or_byte2
-		     - TermWin.font->min_char_or_byte2;
-		 --i >= 0; ) {
-		cw = boldFont->per_char[i].width;
-		MAX_IT(fw, cw);
-	    }
-	if (fw == TermWin.fwidth && fh == TermWin.fheight)
-	    TermWin.boldFont = boldFont;
+	    fw = get_fontwidest(boldFont);
+	    fh = boldFont->ascent + boldFont->descent;
+	    if (fw <= TermWin.fwidth && fh <= TermWin.fheight)
+		TermWin.boldFont = boldFont;
+	    TermWin.bprop = !(fw == TermWin.fwidth /* && fh == TermWin.fheight */ );
+	}
     }
 #endif				/* NO_BOLDFONT */
 
-/* TODO: check that size of Kanji font is okay */
+#ifdef MULTICHAR_SET
+    if (recheckfonts)
+    /* TODO: XXX: This could be much better? */
+	if (TermWin.mfont != NULL) {
+	    int             fh, fw;
+
+	    fw = get_fontwidest(TermWin.mfont);
+	    fh = TermWin.mfont->ascent + TermWin.mfont->descent;
+	    if (fw <= TermWin.fwidth && fh <= TermWin.fheight)
+		/* WHAT TO DO!! */ ;
+	    TermWin.mprop = !(fw == TermWin.fwidth /* && fh == TermWin.fheight */ );
+	}
+#endif
 
     set_colorfgbg();
 
@@ -1053,6 +1050,22 @@ change_font(int init, const char *fontname)
 #undef FNUM_RANGE
     /* NOTREACHED */
 }
+/* INTPROTO */
+int
+get_fontwidest(XFontStruct *f)
+{
+    int             i, cw, fw = 0;
+
+    if (f->min_bounds.width == f->max_bounds.width)
+	return f->min_bounds.width;
+    if (f->per_char == NULL)
+	return 0;
+    for (i = f->max_char_or_byte2 - f->min_char_or_byte2; --i >= 0; ) {
+	cw = f->per_char[i].width;
+	MAX_IT(fw, cw);
+    }
+    return fw;
+}
 /* ------------------------------------------------------------------------- */
 /* INTPROTO */
 void
