@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	xdefaults.c
  *----------------------------------------------------------------------*
- * $Id: xdefaults.c,v 1.34.2.3 1999/07/28 20:22:39 mason Exp $
+ * $Id: xdefaults.c,v 1.34.2.4 2000/03/09 09:41:36 mason Exp $
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (C) 1994      Robert Nation <nation@rocket.sanders.lockheed.com>
@@ -104,7 +104,7 @@ static const struct {
          Opt_scrollBar_floating, "scrollbar without a trough"),
     BOOL(Rs_scrollTtyOutput, "scrollTtyOutput", NULL,
          Opt_scrollTtyOutput, NULL),
-    SWCH("si", Opt_Boolean|Opt_Reverse|Opt_scrollTtyOutput,
+    BOOL(Rs_scrollTtyOutput, NULL, "si", Opt_Reverse | Opt_scrollTtyOutput,
 	 "scroll-on-tty-output inhibit"),
     BOOL(Rs_scrollKeypress, "scrollTtyKeypress", "sk",
          Opt_scrollKeypress, "scroll-on-keypress"),
